@@ -6,7 +6,6 @@ use Config;
 use Test::More;
 use File::Basename;
 use Data::Dumper;
-use Archive::Tar;
 use File::Spec;
 use File::Basename qw(fileparse);
 use Config;
@@ -17,13 +16,11 @@ our @ISA = qw( Exporter );
 
 $ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION} = 1;
 
-use Fcntl qw(LOCK_EX LOCK_UN LOCK_SH LOCK_NB);
-
 our @EXPORT = qw(
     expect_flags run_common $RV $S);
 
-my @PC_PATHS = qw(usr/lib/pkgconfig usr/share/pkgconfig
-                usr/local/lib/pkgconfig usr/local/share/pkgconfig);
+my @PC_PATHS = qw(data/usr/lib/pkgconfig data/usr/share/pkgconfig
+                data/usr/local/lib/pkgconfig data/usr/local/share/pkgconfig);
                 
 
 
@@ -43,7 +40,7 @@ $ENV{PKG_CONFIG_PATH} = join($Config{path_sep}, @PC_PATHS);
 our $RV;
 our $S;
 
-my $SCRIPT = $FindBin::Bin . "/../script/ppkg-config";
+my $SCRIPT = "$FindBin::Bin/../script/ppkg-config";
 
 # Work around git on windows' lamentable lack of symbolic
 # link support
@@ -63,53 +60,6 @@ sub expect_flags {
     like($S, qr/\Q$flags\E/, $msg);
 }
 
-# For concurrency, it is necessary to maintain a lock here. The
-# lock should remain in place
-sub extract_our_tarball
-{
-    open my $fh, "+<", $LOCK or die "$LOCK: $!";
-    my $extract_dir = File::Spec->catfile($FindBin::Bin, 'usr');
-
-    do {
-        local $SIG{ALRM} = sub { die 'timeout waiting for lock' };
-        alarm 10;
-        flock($fh, LOCK_EX); # Block.
-        alarm 0;
-    };
-    
-    # If we have a shared lock, let us check if the directory exists:
-    if (-d $extract_dir) {
-        return;
-    }
-    
-    my $tar = Archive::Tar->new($TARBALL);
-    my $cwd = cwd();
-    chdir $FindBin::Bin;
-    $tar->extract;
-    chdir $cwd;
-}
-
-sub import {
-    extract_our_tarball();
-    goto &Exporter::import;
-}
-
-sub get_my_file_list {
-    plan skip_all => 'skip long running tests on ActiveState PPM build'
-      if $ENV{ACTIVESTATE_PPM_BUILD};
-    my $pmfile = shift;
-    my $needed = fileparse($pmfile, ".pm",".t");
-    ($needed) = ($needed =~ /(FLIST.+)/);
-    die "Invalid file $pmfile" unless $needed;
-    my $file_list = File::Spec->catfile($FindBin::Bin, $needed);
-    open my $fh, "<", $file_list or die "$file_list: $!";
-    note $file_list;
-    my @lines = <$fh>;
-    @lines = map { $_ =~ s/\s+$//g; $_ } @lines;
-    @lines = map { File::Spec->catfile($FindBin::Bin, $_) } @lines;
-    return \@lines;
-}
-
 sub run_exists_test {
     my ($flist,$pmfile) = @_;
     note "$pmfile: Will perform --exist tests";
